@@ -1,6 +1,9 @@
+from __future__ import annotations
+
 from argparse import Namespace
 
 import pytest
+from python_discovery import PythonInfo
 
 from virtualenv.activation import (
     BashActivator,
@@ -10,7 +13,6 @@ from virtualenv.activation import (
     PowerShellActivator,
     PythonActivator,
 )
-from virtualenv.discovery.py_info import PythonInfo
 
 
 @pytest.mark.parametrize(
