@@ -7,12 +7,14 @@ from pathlib import Path
 from subprocess import Popen
 
 import pytest
+from python_discovery import PythonInfo
 
-from virtualenv.discovery.py_info import PythonInfo
 from virtualenv.run import cli_run
+from virtualenv.run.plugin.creators import CreatorSelector
+from virtualenv.seed.wheels.embed import BUNDLE_FOLDER as EMBED_WHEEL_DIR
 
 CURRENT = PythonInfo.current_system()
-CREATOR_CLASSES = CURRENT.creators().key_to_class
+CREATOR_CLASSES = CreatorSelector.for_interpreter(CURRENT).key_to_class
 
 
 def builtin_shows_marker_missing():
@@ -26,6 +28,7 @@ def builtin_shows_marker_missing():
     return not marker.exists()
 
 
+@pytest.mark.slow
 @pytest.mark.xfail(
     condition=bool(os.environ.get("CI_RUN")),
     strict=False,
@@ -35,7 +38,7 @@ def builtin_shows_marker_missing():
     not Path(CURRENT.system_include).exists() and not builtin_shows_marker_missing(),
     reason="Building C-Extensions requires header files with host python",
 )
-@pytest.mark.parametrize("creator", [i for i in CREATOR_CLASSES.keys() if i != "builtin"])
+@pytest.mark.parametrize("creator", [i for i in CREATOR_CLASSES if i != "builtin"])
 def test_can_build_c_extensions(creator, tmp_path, coverage_env):
     env, greet = tmp_path / "env", str(tmp_path / "greet")
     shutil.copytree(str(Path(__file__).parent.resolve() / "greet"), greet)
@@ -45,6 +48,8 @@ def test_can_build_c_extensions(creator, tmp_path, coverage_env):
         str(session.creator.script("pip")),
         "install",
         "--no-index",
+        "--find-links",
+        str(EMBED_WHEEL_DIR),
         "--no-deps",
         "--disable-pip-version-check",
         "-vvv",
