@@ -35,7 +35,7 @@ from virtualenv.util.subprocess import CREATE_NO_WINDOW
 
 @pytest.fixture(autouse=True)
 def _clear_pypi_info_cache():
-    from virtualenv.seed.wheels.periodic_update import _PYPI_CACHE
+    from virtualenv.seed.wheels.periodic_update import _PYPI_CACHE  # noqa: PLC0415
 
     _PYPI_CACHE.clear()
 
@@ -49,14 +49,7 @@ def test_manual_upgrade(session_app_data, caplog, mocker, for_py_version):
         "manual",
     )
 
-    def _do_update(  # noqa: PLR0913
-        distribution,
-        for_py_version,  # noqa: ARG001
-        embed_filename,  # noqa: ARG001
-        app_data,  # noqa: ARG001
-        search_dirs,  # noqa: ARG001
-        periodic,  # noqa: ARG001
-    ):
+    def _do_update(distribution, **_kwargs):
         if distribution == "pip":
             return [new_version]
         return []
@@ -70,11 +63,11 @@ def test_manual_upgrade(session_app_data, caplog, mocker, for_py_version):
     assert " new entries found:\n" in caplog.text
     assert "\tNewVersion(" in caplog.text
     packages = defaultdict(list)
-    for i in do_update_mock.call_args_list:
-        packages[i[1]["distribution"]].append(i[1]["for_py_version"])
+    for args in do_update_mock.call_args_list:
+        packages[args[1]["distribution"]].append(args[1]["for_py_version"])
     packages = {key: sorted(value) for key, value in packages.items()}
     versions = sorted(BUNDLE_SUPPORT.keys())
-    expected = {"setuptools": versions, "wheel": versions, "pip": versions}
+    expected = {"setuptools": versions, "wheel": ["3.8"], "pip": versions}
     assert packages == expected
 
 
@@ -101,8 +94,6 @@ def test_pick_periodic_update(tmp_path, mocker, for_py_version):
             "--no-pip",
             "--setuptools",
             "bundle",
-            "--wheel",
-            "bundle",
         ],
     )
 
@@ -280,6 +271,7 @@ def test_trigger_update_no_debug(for_py_version, session_app_data, tmp_path, moc
     monkeypatch.delenv("_VIRTUALENV_PERIODIC_UPDATE_INLINE", raising=False)
     current = get_embed_wheel("setuptools", for_py_version)
     process = mocker.MagicMock()
+    process.pid = 123
     process.communicate.return_value = None, None
     Popen = mocker.patch("virtualenv.seed.wheels.periodic_update.Popen", return_value=process)  # noqa: N806
 
@@ -316,7 +308,7 @@ def test_trigger_update_no_debug(for_py_version, session_app_data, tmp_path, moc
     )
 
     assert args == ([sys.executable, "-c", cmd],)
-    expected = {"stdout": subprocess.PIPE, "stderr": subprocess.PIPE}
+    expected = {"stdout": subprocess.DEVNULL, "stderr": subprocess.DEVNULL}
     if sys.platform == "win32":
         expected["creationflags"] = CREATE_NO_WINDOW
     assert kwargs == expected
@@ -328,6 +320,7 @@ def test_trigger_update_debug(for_py_version, session_app_data, tmp_path, mocker
     current = get_embed_wheel("pip", for_py_version)
 
     process = mocker.MagicMock()
+    process.pid = 123
     process.communicate.return_value = None, None
     Popen = mocker.patch("virtualenv.seed.wheels.periodic_update.Popen", return_value=process)  # noqa: N806
 
@@ -453,15 +446,7 @@ def test_do_update_skip_already_done(tmp_path, mocker, time_freeze):
     extra = tmp_path / "extra"
     extra.mkdir()
 
-    def _download_wheel(  # noqa: PLR0913
-        distribution,  # noqa: ARG001
-        version_spec,  # noqa: ARG001
-        for_py_version,  # noqa: ARG001
-        search_dirs,  # noqa: ARG001
-        app_data,  # noqa: ARG001
-        to_folder,  # noqa: ARG001
-        env,  # noqa: ARG001
-    ):
+    def _download_wheel(**_kwargs):
         return wheel.path
 
     download_wheel = mocker.patch("virtualenv.seed.wheels.acquire.download_wheel", side_effect=_download_wheel)
@@ -502,8 +487,9 @@ def test_do_update_skip_already_done(tmp_path, mocker, time_freeze):
 
 
 def test_new_version_eq():
-    value = NewVersion("a", datetime.now(tz=timezone.utc), datetime.now(tz=timezone.utc), "periodic")
-    assert value == value
+    now = datetime.now(tz=timezone.utc)
+    value = NewVersion("a", now, now, "periodic")
+    assert value == NewVersion("a", now, now, "periodic")
 
 
 def test_new_version_ne():
@@ -557,7 +543,7 @@ def mock_download(mocker, pip_version_remote):
     do = download()
     return mocker.patch(
         "virtualenv.seed.wheels.acquire.download_wheel",
-        side_effect=lambda *a, **k: next(do),  # noqa: ARG005
+        side_effect=lambda *_a, **_k: next(do),
     )
 
 
@@ -651,7 +637,7 @@ def test_download_periodic_stop_at_first_usable(tmp_path, mocker, time_freeze):
     rel_date_gen = iter(rel_date_remote)
     release_date = mocker.patch(
         "virtualenv.seed.wheels.periodic_update.release_date_for_wheel_path",
-        side_effect=lambda *a, **k: next(rel_date_gen),  # noqa: ARG005
+        side_effect=lambda *_a, **_k: next(rel_date_gen),
     )
 
     last_update = _UP_NOW - timedelta(days=14)
@@ -683,7 +669,7 @@ def test_download_periodic_stop_at_first_usable_with_previous_minor(tmp_path, mo
     rel_date_gen = iter(rel_date_remote)
     release_date = mocker.patch(
         "virtualenv.seed.wheels.periodic_update.release_date_for_wheel_path",
-        side_effect=lambda *a, **k: next(rel_date_gen),  # noqa: ARG005
+        side_effect=lambda *_a, **_k: next(rel_date_gen),
     )
 
     last_update = _UP_NOW - timedelta(days=14)
