@@ -10,7 +10,7 @@ def test_wheel_support_no_python_requires(mocker):
     wheel = get_embed_wheel("setuptools", for_py_version=None)
     zip_mock = mocker.MagicMock()
     mocker.patch("virtualenv.seed.wheels.util.ZipFile", new=zip_mock)
-    zip_mock.return_value.__enter__.return_value.read = lambda name: b""  # noqa: ARG005
+    zip_mock.return_value.__enter__.return_value.read = lambda _name: b""
 
     supports = wheel.support_py("3.8")
     assert supports is True
@@ -29,3 +29,8 @@ def test_wheel_not_support():
 def test_wheel_repr():
     wheel = get_embed_wheel("setuptools", MAX)
     assert str(wheel.path) in repr(wheel)
+
+
+def test_unknown_distribution():
+    wheel = get_embed_wheel("unknown", MAX)
+    assert wheel is None
